@@ -51,6 +51,11 @@
 #'   reset. Users should monitor and test this before making
 #'   especially large calls as any systematic issues could create
 #'   sizable inefficiencies.
+#'
+#'   At this time, results are ordered with the most recent following first —
+#'   however, this ordering is subject to unannounced change and eventual
+#'   consistency issues. While this remains true it is possible iteratively build
+#'   follower lists for a user over time.
 #' @seealso
 #'   \url{https://developer.twitter.com/en/docs/accounts-and-users/follow-search-get-users/api-reference/get-followers-ids}
 #' @examples
@@ -191,6 +196,9 @@ get_followers_ <- function(user,
     ## if !retryonratelimit then if necessary exhaust what can with token
     rl <- rate_limit(token, query)
     n.times <- rl[["remaining"]]
+    if (n < (n.times * 5000)) {
+      n.times <- ceiling(n / 5000)
+    }
     f <- scroller(url, n, n.times, type = "followers", token)
     ## drop NULL and parse into data frame
     f <- f[!vapply(f, is.null, logical(1))]
